/* Sample C structure definitions for the VF specification files distributed
   on the VF diskette.
*/

#define INVNBRLEN  14      /* Length of invoice number */
#define VCHRLEN    16      /* Length of voucher number */
#define CHKNBRLEN  8       /* Length of check number */
#define PTRMLEN    50      /* Length of payment terms */
#define ASTERMLEN  12      /* Length of alternate search term */
#define INVNOTELEN 124     /* Length of note field */

/* Structure definition for payment.acq file:  */

  struct invoice {
   	char ordercenter;      /* Order center code */
    char perms;            /* Permissions for other order centers:
                              0x01=viewing,0x02=modifying */
    char type;             /* A=Credit, B=Invoice, F=Free */
    char status;           /* A=New (i.e., not on disk),
                              B=In Process, C=Closed */
    char invnbr[INVNBRLEN];/* The invoice or credit memo number */
    int invdate;           /* The date of the invoice */
    long vendornacn;       /* The supplier NACN */
    int datepaid;          /* Date invoice was closed */
    int nbracqrcds;        /* Number of acq records linked to this invoice */
    double total;          /* Total amount authorized/paid on invoice */
    char voucher[VCHRLEN]; /* Voucher number */
    int vouchdate;         /* Date of voucher */
    int currency;          /* Country code of currency */
    char chknbr[CHKNBRLEN];/* Check number */
    int checkdate;         /* Date of the check */
    double discount;       /* Whole-invoice discount percentage */
    double postage;        /* Postage surcharge */
    char postfy[FYLEN];    /* FY file from which paid */
    unsigned int postfnd;  /* Pointer to fund record */
    double handling;       /* Handling charge */
    char handlfy[FYLEN];
    unsigned int handlfnd;
    double insurance;      /* Insurance charge */
    char insurfy[FYLEN];
    unsigned int insurfnd;
    double salestax;       /* Sales tax */
    char saletxfy[FYLEN];
    unsigned int saletxfnd;
    double localtax;       /* Local tax */
    char lcltxfy[FYLEN];
    unsigned int lcltxfnd;
    double specltax;       /* Special tax */
    char spltxfy[FYLEN];
    unsigned int spltxfnd;
    double bindingfee;     /* Binding fee */
    char bindfy[FYLEN];
    unsigned int bindfnd;
    double othercharges;   /* Other charges*/
    char othrfy[FYLEN];
    unsigned int othrfnd;
    char paymntterms[PTRMLEN];  /* Free-text payment terms */
    char altsterm[ASTERMLEN];   /* Free-text alternate search terms */
    char note[INVNOTELEN]; /* Note */
    long firstpaymnt;      /* Pointer to first payment record on this invoice */
    long lastpaymt;        /* Pointer to last payment record */
    char spare;            /* Unused byte */
    char lock;             /* Lock byte */
  };

/* Structure definition for payment.acq file:  */

#define PAYNOTELEN 62      /* Length of note field */

  struct payment {
    char ordercenter;      /* Order center code */
    char perms;            /* Permissions for other order centers:
                              0X01=viewing, 0X02=modifying */
    int createdby;         /* Pointer into the password file to the record
                              of the user who created the record */
    long invptr;           /* Pointer to the invoice record */
    char prefix[PREFIXLEN];/* This payment's acq record number */
    char pad[4];           /* Compensate for change in ACQ350.h that
                              shortened PREFIXLEN to 4 from 8 */
    unsigned long int seqnbr;   /* The sequence number of the acq record */
    long int acqnbr;       /* The number of the acq record itself */
    int nbrcpys;           /* Number of copies paid on this payment */
    double cost;           /* Amount authorized/paid for item(s) */
    int currency;          /* Pointer to currency conversion country */
    double discount;       /* Whole-invoice discount percentage */
    char fiscalyr[FYLEN];  /* FY file from which paid. If fiscalyr[0] == '<',
                              there is a split fund record */
    unsigned int fndnbr;   /* Pointer to fund record or to the split fund
                              record if there is one */
    char note[PAYNOTELEN]; /* Note */
    long nextpaymnt;       /* Pointer to next payment record on this invoice */
    long prevpaymnt;       /* Pointer to the previous payment record on this
                              invoice */
    char type;             /* 'A'= Credit, 'B' = Invoice, 'F' = Free */
    char lock;             /* Lock byte */
  };

/* Structure definition for file ordercen.acq:  */

  struct ocentype {
  char orcntrptr[4];
  char ocen[16];
  int perm1;
  int perm2;
  char unused[8];
};

/* Structure definition for file funds\*.fy */

struct fund {
  char ordercenter;         /* Order center owning the record */
  char perms;               /* Permissions for other order centers:
                               0x01=viewing, 0x02=modifying */
  char status;              /* O=Open: C=Closed: F=Frozen: D=Deleted */
  char spare;               /* Not currently used */
  int daycreated;           /* Date fund was created.  Used during reporting
                               expenditures by month as an offset into an array
                               of long integers. */
  char number[NMLEN];       /* User-defined fund "Number" */
  char name[4][NMLEN];      /* Hierarchical fund name */
  char altname[ALTNMLEN];   /* Alternate name */
  char restriction[40];     /* Free text fund restriction */
  char source[40];          /* Free-text source of fund */
  int revday;               /* Reversion date of fund */
  double budgeted;            /* Current budgeted amount */
  double ordencumbrd;         /* Regular order encumbrance */
  double contencmbrd;         /* Continuations encumbrance */
  double expended;            /* Amount expended from the fund */
  double contexpended;        /* Cumulative total of continuation expenditures */
  double pendingexpend;       /* Pending expenditures--invoices authorized but not
                               closed */
  double ovrexpended;         /* Overexpenditure limit */
  double ovrencumbrd;         /* Overencumbrance limit */
  char note[286];             /* Note */  /* 860221 MCL - used to be 306 */
                              /* Below two variables added 860221 */
  char fromencum[10];         /* Name of fiscal file that encumbrances were
                                 transferred from */
  char toencum[10];           /* Name of fiscal year file that encumbrances
                                 transferred to */
  char lock;                /* Lock byte-last byte in record */
};


